/**
Un conto corrente e' definito per un utente, si puo' depositare
del denaro del conto, prelevare il denaro, verificare il denaro
presente nel conto e controllare il nome dell'utente.
*/

public class ContoCorrente implements Comparable{

    static private int count=0; // contatore
    private int num; // numero di CC (univoco)    
	private double saldo; // il saldo del conto
    private String nome; // il nome dell'utente
    
    { num = ++count; } //inizializzatore d'istanza

    /**
       Costruisce il conto di un utente di nome assegnato.
       @param nm nome dell'utente.
     */
    public ContoCorrente(String nm) {
	nome = nm;
	saldo = 0;
    }
    
    /**
    Costruisce il conto di un utente con nome e saldo assegnati.
    @param nm nome dell'utente.
    @param saldo saldo iniziale del conto corrente.
  */
    public ContoCorrente(String nm, double saldo) {
	nome = nm;
	this.saldo = saldo;
    }

    /**
       Restituisce il nome dell'utente.
       @return nome dell'utente.
     */
    public String nomeUtente() {
	return nome;
    }
    
    /**
    Restituisce il saldo del CC.
    @return saldo.
  */
    public double saldoConto() {
	return saldo;
 }


    /** 
	Deposita del denaro.
	@param denaro la somma depositata.
     */
    public void deposita(double denaro) {
	saldo += denaro;
    }

    /**
       Ritira denaro
       @param somma somma da ritirare.
    */
    public void ritira(double somma) {
	saldo -= somma;
    }

    /**
       Mostra il denaro depositato.
       @return denaro depositato.
    */
       public double mostraConto() {
	   return saldo;
       }
       
       
       /**
       Mostra il conto corrente.
       @return descrizione testuale del conto corrente.
     */
      	public String toString() {
      		return "CC n. "+ num + "; Nome: " + nome + "; Saldo:" + saldo;
      	}
       

      	public boolean equals(Object obj) {
      		if (obj == null) return false;
      		if (!(obj instanceof ContoCorrente)) return false;
      		ContoCorrente p = (ContoCorrente) obj;
      		return (num == p.num);
      	}
      	
        /**
        Confronta il saldo di due conti correnti.
        */
      	public int compareTo(Object obj) {
       		if (saldo < ((ContoCorrente)obj).saldo) return -1;
       		else if (saldo > ((ContoCorrente)obj).saldo) return 1;
       			 else return 0;
       	}


}  // fine classe ContoCorrente
